@@ -2,7 +2,6 @@ package org.gcube.portlets.user.gisviewer.client;
 
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
@@ -14,7 +13,6 @@ import org.gcube.portlets.user.gisviewer.client.commons.beans.GeoInformationForW
 import org.gcube.portlets.user.gisviewer.client.commons.beans.GeoserverItem;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.GisViewerBaseLayerInterface;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
-import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItemsResult;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.MapViewInfo;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.TransectParameters;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.WebFeatureTable;
@@ -69,8 +67,8 @@ import com.google.gwt.user.client.ui.Label;
 /**
  * The Class GisViewerPanel.
  * @author Ceras
- * updated by Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
- * Sep 28, 2015
+ * @author updated by Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
+ * Sep 26, 2016
  */
 public class GisViewerPanel extends LayoutContainer
 implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandler, OpenLayersHandler {
@@ -186,13 +184,6 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 		}
 
 		getTransectUrl();
-
-		if (parameters.getOpeningGroup()!=null) {
-			addGroupByGroupName(parameters.getOpeningGroup());
-		}
-		else if (parameters.getOpeningLayers()!=null) {
-			addLayersByLayerNames(parameters.getOpeningLayers());
-		}
 	};
 
 	/**
@@ -233,161 +224,6 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 		});
 	}
 
-	/**
-	 * Adds the group by group name.
-	 *
-	 * @param groupName the group name
-	 */
-	public void addGroupByGroupName(final String groupName) {
-		waitMessage(true);
-		gisViewerServiceAsync.getGroupsInfo(groupName, new AsyncCallback<LayerItemsResult>() {
-			@Override
-			public void onSuccess(LayerItemsResult result) {
-				waitMessage(false);
-				if (!result.getStatus().equals("")) {
-					MessageBox.alert("Error", result.getStatus(), null);
-				}
-
-				if (result.getLayerItemsSize()!=0) {
-					List<LayerItem> layerItems = result.getLayerItems();
-					addLayersOnMap(layerItems, false);
-					showLayer(layerItems.get(layerItems.size()-1)); // show last layer
-				}
-			}
-
-			@Override
-			public void onFailure(Throwable caught) {
-				waitMessage(false);
-				Window.alert("The layers doesn't exist");
-			}
-		});
-	}
-
-	/**
-	 * Adds the layers by layer names.
-	 *
-	 * @param layerNames the layer names
-	 */
-	public void addLayersByLayerNames(String ... layerNames) {
-		 addLayersByLayerNames(Arrays.asList(layerNames));
-	}
-
-	/**
-	 * Adds the layers by layer names.
-	 *
-	 * @param layerNames the layer names
-	 */
-	public void addLayersByLayerNames(List<String> layerNames) {
-		addLayersByLayerNames(layerNames, false);
-	}
-
-	/**
-	 * Adds the layers by layer names to top.
-	 *
-	 * @param layerNames the layer names
-	 */
-	public void addLayersByLayerNamesToTop(final List<String> layerNames) {
-		addLayersByLayerNames(layerNames, true);
-	}
-
-	/**
-	 * Adds the layers by layer items.
-	 *
-	 * @param layerItems the layer items
-	 */
-	public void addLayersByLayerItems(List<LayerItem> layerItems) {
-		addLayersByLayerItems(layerItems, false);
-	}
-
-	/**
-	 * Adds the layer by layer item.
-	 *
-	 * @param layerItem the layer item
-	 */
-	public void addLayerByLayerItem(LayerItem layerItem) {
-		List<LayerItem> layerItems = new ArrayList<LayerItem>();
-		layerItems.add(layerItem);
-		addLayersByLayerItems(layerItems, false);
-	}
-
-	/**
-	 * Adds the layers by layer items to top.
-	 *
-	 * @param layerItems the layer items
-	 */
-	public void addLayersByLayerItemsToTop(List<LayerItem> layerItems) {
-		addLayersByLayerItems(layerItems, true);
-	}
-
-	/**
-	 * Adds the layer by layer item to top.
-	 *
-	 * @param layerItem the layer item
-	 */
-	public void addLayerByLayerItemToTop(LayerItem layerItem) {
-		List<LayerItem> layerItems = new ArrayList<LayerItem>();
-		layerItems.add(layerItem);
-		addLayersByLayerItems(layerItems, true);
-	}
-
-	/**
-	 * Adds the layers by layer names.
-	 *
-	 * @param layerNames the layer names
-	 * @param toTop the to top
-	 */
-	private void addLayersByLayerNames(final List<String> layerNames, final boolean toTop) {
-		waitMessage(true);
-		gisViewerServiceAsync.getLayersInfo(layerNames, new AsyncCallback<LayerItemsResult>() {
-			@Override
-			public void onSuccess(LayerItemsResult result) {
-				waitMessage(false);
-				if (!result.getStatus().equals("")) {
-					MessageBox.alert("Error", result.getStatus(), null);
-				}
-
-				if (result.getLayerItemsSize()!=0) {
-					addLayersOnMap(result.getLayerItems(), toTop);
-				}
-			}
-
-			@Override
-			public void onFailure(Throwable caught) {
-				waitMessage(false);
-				Window.alert("The layers doesn't exist");
-			}
-		});
-	}
-
-	/**
-	 * Adds the layers by layer items.
-	 *
-	 * @param layerItems the layer items
-	 * @param onTop the on top
-	 */
-	private void addLayersByLayerItems(List<LayerItem> layerItems, final boolean onTop) {
-		waitMessage(true);
-		gisViewerServiceAsync.getLayersInfoByLayerItems(layerItems, new AsyncCallback<LayerItemsResult>() {
-			@Override
-			public void onSuccess(LayerItemsResult result) {
-				waitMessage(false);
-				if (!result.getStatus().equals("")) {
-					MessageBox.alert("Error", result.getStatus(), null);
-				}
-
-				if (result.getLayerItemsSize()!=0) {
-					addLayersOnMap(result.getLayerItems(), onTop);
-				}
-			}
-
-			@Override
-			public void onFailure(Throwable caught) {
-				waitMessage(false);
-				Window.alert("The layers doesn't exist");
-			}
-		});
-	}
-
 	/**
 	 * Adds the layer by wms.
 	 *
@@ -397,7 +233,8 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 	 * @param isBase the is base
 	 * @param displayInLayerSwitcher the display in layer switcher
 	 * @param UUID the uuid
-	 * {@link #addLayerByWmsRequest(LayerType, String, String, String, boolean, boolean, String, boolean)}
+	 *
+	 * {use @link {@link GisViewerPanel#addLayerByWmsRequest(String, String, String, boolean, boolean, String, boolean)}}
 	 */
 	@Deprecated
 	public void addLayerByWms(String layerTitle, String layerName, String wmsRequest, boolean isBase, boolean displayInLayerSwitcher, String UUID) {
@@ -423,9 +260,6 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 		}
 	}
 
-
-
-
 	/**
 	 * Adds the layer by wms request.
 	 *
@@ -466,6 +300,7 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 				if(layersPanel.isMasked())
 					layersPanel.unmask();
 
+				GWT.log("Add Layer By WMS: "+result.getMapWMSNoStandard() + ", and isNCWMS? "+result.isNcWMS());
 				addLayerByWms(featureType, layerTitle, layerName, result.getBaseWmsServiceHost(), true, isBase, displayInLayerSwitcher, (ArrayList<String>) result.getStyles().getGeoStyles(), result.getWmsRequest(), false, result.getMapWMSNoStandard(), result.isNcWMS(), UUID, result.getZAxis());
 			}
 		});
@@ -677,6 +512,7 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 			}
 		}
 
+		GWT.log(url);
 		final FlexTable flexTable = new FlexTable();
 		flexTable.setStyleName("tablelegend");
 		flexTable.setWidget(0, 0, new Label("Style"));
@@ -1091,15 +927,6 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 		return geoserverItems;
 	}
 
-	/**
-	 * Adds the group.
-	 *
-	 * @param groupName the group name
-	 */
-	public void addGroup(String groupName) {
-		this.addGroupByGroupName(groupName);
-	}
-
 	/* (non-Javadoc)
 	 * @see org.gcube.portlets.user.gisviewer.client.layerspanel.LayersPanelHandler#updateLayersOrder()
 	 */
